@@ -7,7 +7,7 @@ use Net::EPP::ResponseCodes;
 use Net::EPP::Simple;
 use strict;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 1;
 
@@ -17,18 +17,17 @@ __END__
 
 =head1 NAME
 
-Net::EPP - a Perl library for the Extensible Provisioning Protocol (EPP)
+Net::EPP - a Perl library for the Extensible Provisioning Protocol (EPP).
 
 =head1 DESCRIPTION
 
 EPP is the Extensible Provisioning Protocol. EPP (defined in
-L<RFC 5730|https://www.rfc-editor.org/rfc/rfc5730.html>) is an application-
-layer client-server protocol for the provisioning and management of objects
-stored in a shared central repository. Specified in XML, the protocol
-defines generic object management operations and an extensible framework
-that maps protocol operations to objects. As of writing, its only well-
-developed application is the provisioning of domain names, hosts, and
-related contact details.
+L<STD 69|https://www.rfc-editor.org/info/std69>) is an application-layer
+client-server protocol for the provisioning and management of objects stored in
+a shared central repository. Specified in XML, the protocol defines generic
+object management operations and an extensible framework that maps protocol
+operations to objects. As of writing, its only well-developed application is the
+provisioning of domain names, hosts, and related contact details.
 
 This package offers a number of Perl modules which implement various EPP-
 related functions:
@@ -48,11 +47,21 @@ related functions:
 
 =back
 
+=head1 SEE ALSO
+
+=over
+
+=item * L<Net::EPP::Server> - an EPP server implementation.
+
+=item * L<App::pepper> - a command-line EPP client.
+
+=back
+
 =head1 AUTHORS
 
-This module was originally developed by CentralNic
-(L<https://centralnicregistry.com/>), with the assistance of other
-contributors around the world, including (but not limited to):
+This module is maintained by L<Gavin Brown|https://metacpan.org/author/GBROWN>,
+with the assistance of other contributors around the world, including (but not
+limited to):
 
 =over
 
@@ -76,11 +85,14 @@ contributors around the world, including (but not limited to):
 
 =item * Christian Maile
 
+=item * Tony Finch
+
 =back
 
 =head1 COPYRIGHT
 
-This module is (c) 2008 - 2023 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
+This module is (c) 2008 - 2023 CentralNic Ltd and 2024 Gavin Brown. This module
+is free software; you can redistribute it and/or modify it under the same terms
+as Perl itself.
 
 =cut
